@@ -9,20 +9,25 @@ d = {r: c, appName: navigator.appName, appVersion: navigator.appVersion}
 
 """
 
+
 async def page_ready(self, msg):
     jp.run_task(self.run_javascript(js_string))
 
+
 async def result_ready(self, msg):
-    msg.page.result_div.text = f'The result is: {msg.result}'
+    msg.page.result_div.text = f"The result is: {msg.result}"
+
 
 def result_test():
     wp = jp.WebPage()
-    wp.on('page_ready', page_ready)
-    wp.on('result_ready', result_ready)
-    wp.result_div = jp.Div(text='Result will go here', classes='m-4 p-2 text-xl', a=wp)
-    jp.Pre(text=js_string, a=wp, classes='m-2 p-2 border')
+    wp.on("page_ready", page_ready)
+    wp.on("result_ready", result_ready)
+    wp.result_div = jp.Div(text="Result will go here", classes="m-4 p-2 text-xl", a=wp)
+    jp.Pre(text=js_string, a=wp, classes="m-2 p-2 border")
     return wp
 
+
 # initialize the demo
-from  examples.basedemo import Demo
-Demo ("result_test",result_test)
+from examples.basedemo import Demo
+
+Demo("result_test", result_test)
