@@ -10,7 +10,7 @@ from tests.basetest import Basetest
 import io
 from contextlib import redirect_stdout
 import pprint
-
+import sys
 
 class TestImportability(Basetest):
     """
@@ -28,11 +28,13 @@ class TestImportability(Basetest):
             assert justpy
             outputText = outputBuf.getvalue()
         debug = self.debug
-        # debug=True
+        jp_refcount=sys.getrefcount("justpy")
+        debug=True
         if debug:
-            print(outputText)
-        self.assertTrue("Module directory" in outputText)
-        self.assertTrue("Application directory" in outputText)
+            print(f"{jp_refcount}:{outputText}")
+        if jp_refcount<=16:
+            self.assertTrue("Module directory" in outputText)
+            self.assertTrue("Application directory" in outputText)
         # https://stackoverflow.com/questions/34861137/list-all-the-elements-in-a-python-namespace
         names = dir(justpy)
         if debug:
